from setuptools import setup

setup(
    name='zsearch', 
    version='1.02', 
    description='The Head First Python Search Tools',
    author='HF Python 2e',
    author_email='azeltov@gmail.com',
    url='https://github.com/azeltov/adb_workshop',
    py_modules=['zsearch'],
    python_requires='>=3.6',
)
